<?php
/**
 * Plugin Name: WooCommerce One-Click Buy
 * Description: Добавя бутон "Купи с един клик" и записва информация за поръчката в админ панела.
 * Version: 1.3.9
 * Author: Vladislaw / <a href="https://wpplug.info">wpplug.info</a>
 * License: GPL2
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

function create_one_click_orders_table() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'one_click_orders';
    
    if ($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {
        $charset_collate = $wpdb->get_charset_collate();
        
        $sql = "CREATE TABLE $table_name (
            id mediumint(9) NOT NULL AUTO_INCREMENT,
            product_id bigint(20) NOT NULL,
            name varchar(255) NOT NULL,
            phone varchar(255) NOT NULL,
            status varchar(255) DEFAULT 'В Обработка' NOT NULL,
            created_at datetime DEFAULT CURRENT_TIMESTAMP NOT NULL,
            PRIMARY KEY (id)
        ) $charset_collate;";

        require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
        dbDelta( $sql );
    }
}

register_activation_hook( __FILE__, 'create_one_click_orders_table' );

function add_one_click_button() {
    $button_color = get_option('one_click_button_color', '#28a745');
    $button_position = get_option('one_click_button_position', 'after_add_to_cart');

    if ($button_position == 'after_add_to_cart') {
        add_action('woocommerce_after_add_to_cart_button', 'add_one_click_button_after_add_to_cart', 10);
    } elseif ($button_position == 'before_add_to_cart') {
        add_action('woocommerce_before_add_to_cart_button', 'add_one_click_button_after_add_to_cart', 10);
    } elseif ($button_position == 'after_product_title') {
        add_action('woocommerce_single_product_summary', 'add_one_click_button_after_add_to_cart', 35);
    }
}

function add_one_click_button_after_add_to_cart() {
    $button_color = get_option('one_click_button_color', '#28a745');
    echo '<button class="one-click-buy" id="one-click-buy-button" style="background-color:' . esc_attr($button_color) . '; margin-top: 10px;">Купи с един клик</button>';
    echo '<style>.single-product .product .single_add_to_cart_button { margin-bottom: 20px; }</style>';
}

add_action('wp', 'add_one_click_button');

function one_click_modal() {
    wp_enqueue_style('one-click-modal-style', plugin_dir_url(__FILE__) . 'style.css');
    ?>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">

<div id="one-click-modal" style="display: none;">
    <div class="one-click-modal-content">
        <i class="fas fa-user-circle icon"></i>
        <h3>Попълнете Вашите данни</h3>
        <form id="one-click-form">
            <div class="input-group">
                <i class="fas fa-user input-icon"></i>
                <input type="text" id="name" name="name" placeholder="Вашето име" required>
            </div>
            <div class="input-group">
                <i class="fas fa-phone-alt input-icon"></i>
                <input type="text" id="phone" name="phone" placeholder="Вашият телефон" required>
            </div>
            <input type="hidden" id="product-id" name="product_id" value="">
            <div class="input-group">
                <label for="terms_conditions" class="checkbox-label">
                    <input type="checkbox" id="terms_conditions" name="terms_conditions" required>
                    Запознат съм с <a href="<?php echo get_option('terms_conditions_url', '#'); ?>" target="_blank" class="terms-link">Общите условия</a> на сайта.
                </label>
            </div>
            <button type="submit" class="submit-btn">Поръчай сега</button>
            <h5>След направената поръчка наш служител ще се свърже с Вас!</h5>
        </form>
    </div>
</div>

    <div id="success-modal" style="display: none;">
        <div class="success-modal-content">
            <h3>Вашата поръчка беше записана успешно!</h3>
            <p>Очаквайте наш оператор да се свърже с вас!</p>
        </div>
    </div>
    
    <script>
    jQuery(document).ready(function($) {
        $('#one-click-buy-button').on('click', function(event) {
            event.preventDefault();
            var productId = '<?php echo get_the_ID(); ?>';
            $('#product-id').val(productId);
            $('#one-click-modal').fadeIn();
        });

        $('#close-modal').on('click', function() {
            $('#one-click-modal').fadeOut();
        });

$('#one-click-form').on('submit', function(e) {
    e.preventDefault();
    var form = $(this);
    var name = form.find('#name').val();
    var phone = form.find('#phone').val();
    var productId = form.find('#product-id').val();
    var termsConditions = form.find('#terms_conditions').is(':checked');

    if (!termsConditions) {
        alert('Моля, приемете Общите условия.');
        return;
    }

            $.ajax({
                url: '<?php echo admin_url("admin-ajax.php"); ?>',
                method: 'POST',
                data: {
                    action: 'save_one_click_order',
                    name: name,
                    phone: phone,
                    product_id: productId
                },
                success: function(response) {
                    $('#one-click-modal').fadeOut();
                    $('#success-modal').fadeIn();
                }
            });
        });

        $(document).on('click', function(e) {
            if ($(e.target).is('#one-click-modal')) {
                $('#one-click-modal').fadeOut();
            }
            if ($(e.target).is('#success-modal')) {
                $('#success-modal').fadeOut();
            }
        });
    });
    </script>
    <?php
}

add_action( 'wp_footer', 'one_click_modal' );

function save_one_click_order() {
    if (isset($_POST['name']) && isset($_POST['phone']) && isset($_POST['product_id'])) {
        global $wpdb;
        $table_name = $wpdb->prefix . 'one_click_orders';
        
        $name = sanitize_text_field($_POST['name']);
        $phone = sanitize_text_field($_POST['phone']);
        $product_id = intval($_POST['product_id']);
        
        $wpdb->insert(
            $table_name,
            array(
                'name' => $name,
                'phone' => $phone,
                'product_id' => $product_id
            )
        );

		$admin_email = get_option('admin_email');
		$subject = 'Нова поръчка с един клик';
		$message = 'Има нова поръчка с един клик. Детайли:' . "\n\n";
		$message .= 'Име: ' . $name . "\n";
		$message .= 'Телефон: ' . $phone . "\n";

        wp_mail($admin_email, $subject, $message);
    }
    wp_die();
}

add_action('wp_ajax_save_one_click_order', 'save_one_click_order');
add_action('wp_ajax_nopriv_save_one_click_order', 'save_one_click_order');

function one_click_orders_menu() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'one_click_orders';

    $pending_orders_count = $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE status = 'В Обработка'");

    $menu_title = 'Бърза поръчка';
    if ($pending_orders_count > 0) {
        $menu_title .= ' (' . $pending_orders_count . ')';
    }

    add_menu_page(
        $menu_title,
        $menu_title,
        'manage_options',
        'one-click-orders',
        'one_click_orders_page',
        'dashicons-cart',
        20
    );

    add_submenu_page(
        'one-click-orders',
        'Настройки на Купи с един клик',
        'Настройки',
        'manage_options',
        'one-click-buy-settings',
        'one_click_buy_settings_page'
    );
}

add_action('admin_menu', 'one_click_orders_menu');

function one_click_buy_settings_page() {
    if (isset($_POST['button_color'])) {
        update_option('one_click_button_color', sanitize_hex_color($_POST['button_color']));
    }

    if (isset($_POST['button_position'])) {
        update_option('one_click_button_position', sanitize_text_field($_POST['button_position']));
    }

    if (isset($_POST['terms_conditions_url'])) {
        update_option('terms_conditions_url', esc_url($_POST['terms_conditions_url']));
    }

    $button_color = get_option('one_click_button_color', '#28a745');
    $button_position = get_option('one_click_button_position', 'after_add_to_cart');
    $terms_conditions_url = get_option('terms_conditions_url', '#');
    ?>
    <div class="wrap">
        <h1>Настройки на Купи с един клик</h1>
        <form method="post">
            <label for="button_color">Цвят на бутона "Купи с един клик":</label>
            <input type="text" name="button_color" id="button_color" value="<?php echo esc_attr($button_color); ?>" class="my-color-field" data-default-color="#28a745" />
            <br><br>
            <label for="button_position">Позиция на бутона:</label>
            <select name="button_position" id="button_position">
                <option value="after_add_to_cart" <?php selected($button_position, 'after_add_to_cart'); ?>>След бутона "Добави в количката"</option>
                <option value="before_add_to_cart" <?php selected($button_position, 'before_add_to_cart'); ?>>Пред бутона "Добави в количката"</option>
                <option value="after_product_title" <?php selected($button_position, 'after_product_title'); ?>>След заглавието на продукта</option>
            </select>
            <br><br>
            <label for="terms_conditions_url">Линк към Общите условия:</label>
            <input type="url" name="terms_conditions_url" id="terms_conditions_url" value="<?php echo esc_url($terms_conditions_url); ?>" />
            <br><br>
            <input type="submit" value="Запази" class="button button-primary">
        </form>
    </div>
    <?php
}

function one_click_orders_page() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'one_click_orders';
    $orders = $wpdb->get_results("SELECT * FROM $table_name ORDER BY created_at DESC");

    echo '<h1>Поръчки с един клик</h1>';
    echo '<h4>WooCommerce One Click Buy от <a href="https://wpplug.info">wpplug.info</a> / Версия 1.3.6</h4>';
    echo '<table class="wp-list-table widefat fixed striped">';
    echo '<thead><tr><th>Име</th><th>Телефон</th><th>Продукт</th><th>Дата</th><th>Статус</th><th>Действия</th></tr></thead><tbody>';

    foreach ($orders as $order) {
        $product = wc_get_product($order->product_id);
        $product_url = get_permalink($order->product_id);
        $delete_url = admin_url('admin-ajax.php?action=delete_one_click_order&id=' . $order->id);
        $update_status_url = admin_url('admin-ajax.php?action=update_order_status&id=' . $order->id);
        
        echo '<tr>';
        echo '<td>' . esc_html($order->name) . '</td>';
        echo '<td>' . esc_html($order->phone) . '</td>';
        echo '<td><a href="' . esc_url($product_url) . '" target="_blank">' . esc_html($product->get_name()) . '</a></td>';
        echo '<td>' . esc_html($order->created_at) . '</td>';
        echo '<td><form method="post" action="' . esc_url($update_status_url) . '">
                <select name="status" onchange="this.form.submit()">
				<option value="В Обработка" ' . (isset($order->status) && $order->status == 'В Обработка' ? 'selected' : '') . '>В Обработка</option>
				<option value="Завършена" ' . (isset($order->status) && $order->status == 'Завършена' ? 'selected' : '') . '>Завършена</option>
				<option value="Отказана" ' . (isset($order->status) && $order->status == 'Отказана' ? 'selected' : '') . '>Отказана</option>
</select>
</form></td>
<td><a href="' . esc_url($delete_url) . '" class="button button-secondary">Изтрий</a></td>
</tr>';
}
echo '</tbody></table>';
}

add_action('wp_ajax_delete_one_click_order', 'delete_one_click_order');
function delete_one_click_order() {
    if (isset($_GET['id'])) {
        global $wpdb;
        $table_name = $wpdb->prefix . 'one_click_orders';
        $id = intval($_GET['id']);
        $wpdb->delete($table_name, array('id' => $id));
    }
    wp_redirect(admin_url('admin.php?page=one-click-orders'));
    exit;
}

add_action('wp_ajax_update_order_status', 'update_order_status');
function update_order_status() {
    if (isset($_GET['id']) && isset($_POST['status'])) {
        global $wpdb;
        $table_name = $wpdb->prefix . 'one_click_orders';
        $id = intval($_GET['id']);
        $status = sanitize_text_field($_POST['status']);
        $wpdb->update(
            $table_name,
            array('status' => $status),
            array('id' => $id)
        );
    }
    wp_redirect(admin_url('admin.php?page=one-click-orders'));
    exit;
}
?>
